Path normalization utilities.
Functions
- contains_
glob_ chars - Check if a path contains glob characters.
- expand_
home - Expand ~ to the home directory.
- get_
parent_ path - Get the parent directory path, handling root correctly.
- is_
symlink - Check if a path is a symlink.
- is_
symlink_ outside_ boundary - Check if a resolved symlink path is outside the original path boundary. This prevents escaping the sandbox via symlinks.
- join_
paths - Join paths, handling absolute paths correctly.
- normalize_
case_ for_ comparison - Normalize case for path comparison on case-insensitive filesystems.
- normalize_
path_ for_ sandbox - Normalize a path for sandbox use.
- remove_
trailing_ glob_ suffix - Remove trailing glob suffix (e.g., /** or /*)
- resolve_
symlink - Resolve a symlink to its target, if it is one.